<?php
/**
 * deep-light functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package deep-light
 */

if ( ! defined( 'DEEPLIGHT' ) ) {
	define( 'DEEPLIGHT', '1.0.4' );
}

if ( ! defined( 'DEEP_LIGHT_THEME_DIR' ) ) {
	define( 'DEEP_LIGHT_THEME_DIR', trailingslashit( get_template_directory() ) );
}

if ( ! defined( 'DEEP_LIGHT_THEME_URI' ) ) {
	define( 'DEEP_LIGHT_THEME_URI', trailingslashit( esc_url( get_template_directory_uri() ) ) );
}

if ( ! function_exists( 'deep_light_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function deep_light_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on deep-light, use a find and replace
		 * to change 'deep-light' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'deep-light', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'deep-light' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'deep_light_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'deep_light_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function deep_light_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'deep_light_content_width', 640 );
}
add_action( 'after_setup_theme', 'deep_light_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function deep_light_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'deep-light' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'deep-light' ),
			'before_widget' => '<section id="%1$s" class="title-wrap widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
}
add_action( 'widgets_init', 'deep_light_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function deep_light_scripts() {
	wp_enqueue_style( 'deep-light-style', get_stylesheet_uri(), array(), DEEPLIGHT );
	wp_style_add_data( 'deep-light-style', 'rtl', 'replace' );

	wp_enqueue_script( 'deep-light-navigation', get_template_directory_uri() . '/js/navigation.js', array(), DEEPLIGHT, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'deep_light_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Deep Light Init.
 */
require get_template_directory() . '/inc/class-deep-light-init.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


if ( is_admin() ) {

	/**
	 * Load Plugin Activator.
	 */
	require_once get_template_directory() . '/inc/plugin-activator/deep-light-plugins.php';

	/**
	 * Deep Light Admin
	 */
	require_once get_template_directory() . '/inc/class-deep-light-admin.php';	

}